<?php

namespace Drupal\core_extend\Plugin\Menu;

use Drupal\Core\Menu\LocalTaskDefault;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides title based on the entity's status action.
 */
class ContentEntityModifyStatusTab extends LocalTaskDefault {

  /**
   * Gets the current route definition.
   *
   * @return \Symfony\Component\Routing\Route
   *   The current route definition.
   */
  protected function getRouteDefinition() {
    return $this->routeProvider()->getRouteByName($this->getRouteName());
  }

  /**
   * Gets the current entity's entity type.
   *
   * @return string
   *   The current entity's entity type.
   */
  protected function getEntityTypeId() {
    return $this->getRouteDefinition()->getDefault('_entity_type_id')?:'';
  }

  /**
   * Loads an entity by current entity type.
   *
   * @param int|string $id
   *   The entity id.
   *
   * @return \Drupal\Core\Entity\EntityInterface|null
   *   The loaded entity.
   */
  protected function loadEntity($id) {
    return \Drupal::entityTypeManager()->getStorage($this->getEntityTypeId())->load($id);
  }

  /**
   * Gets the current parameter to check status on.
   *
   * @return string
   *   The current parameter to check status on.
   */
  protected function getParameterName() {
    return $this->getEntityTypeId();
  }

  /**
   * Gets the entity from current route match.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The entity from current route match.
   */
  protected function getEntity() {
    $parameter_name = $this->getParameterName();

    // Return if parameter exists.
    if ($parameter = \Drupal::routeMatch()->getParameter($parameter_name)) {
      return (is_object($parameter)) ? $parameter : $this->loadEntity($parameter);
    }

    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getTitle(Request $request = NULL) {
    if ($entity = $this->getEntity()) {
      $status_key = $entity->getEntityType()->getKey('status');
      $status = $entity->get($status_key)->get(0)->value;
      return (!$status) ? 'Activate' : 'Deactivate';
    }
    return parent::getTitle($request);
  }

}
